# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-11-01 13:39
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('easyaudit', '0010_repr_text'),
    ]

    operations = [
        migrations.AlterField(
            model_name='requestevent',
            name='url',
            field=models.TextField(),
        ),
    ]
