# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2017-06-20 13:54
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('easyaudit', '0003_auto_20170228_1505'),
    ]

    operations = [
        migrations.AlterIndexTogether(
            name='crudevent',
            index_together=set([('object_id', 'content_type')]),
        ),
    ]
