# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-01-25 07:59
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('easyaudit', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='crudevent',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='loginevent',
            name='login_type',
            field=models.SmallIntegerField(choices=[(0, b'Login'), (1, b'Logout'), (2, b'Failed login')]),
        ),
    ]
